#include <kdevplatform/debugger/breakpoint/breakpoint.h>
#include <kdevplatform/debugger/breakpoint/breakpointdetails.h>
#include <kdevplatform/debugger/breakpoint/breakpointmodel.h>
#include <kdevplatform/debugger/breakpoint/breakpointwidget.h>
#include <kdevplatform/debugger/debuggerexport.h>
#include <kdevplatform/debugger/framestack/framestackmodel.h>
#include <kdevplatform/debugger/interfaces/ibreakpointcontroller.h>
#include <kdevplatform/debugger/interfaces/idebugsession.h>
#include <kdevplatform/debugger/interfaces/iframestackmodel.h>
#include <kdevplatform/debugger/interfaces/ivariablecontroller.h>
#include <kdevplatform/debugger/util/treeitem.h>
#include <kdevplatform/debugger/util/treemodel.h>
#include <kdevplatform/debugger/util/treeview.h>
#include <kdevplatform/debugger/variable/variablecollection.h>
#include <kdevplatform/execute/iexecuteplugin.h>
#include <kdevplatform/interfaces/context.h>
#include <kdevplatform/interfaces/contextmenuextension.h>
#include <kdevplatform/interfaces/iassistant.h>
#include <kdevplatform/interfaces/icompletionsettings.h>
#include <kdevplatform/interfaces/icore.h>
#include <kdevplatform/interfaces/idebugcontroller.h>
#include <kdevplatform/interfaces/idocument.h>
#include <kdevplatform/interfaces/idocumentation.h>
#include <kdevplatform/interfaces/idocumentationcontroller.h>
#include <kdevplatform/interfaces/idocumentationprovider.h>
#include <kdevplatform/interfaces/idocumentcontroller.h>
#include <kdevplatform/interfaces/iextension.h>
#include <kdevplatform/interfaces/ilanguage.h>
#include <kdevplatform/interfaces/ilanguagecontroller.h>
#include <kdevplatform/interfaces/ilaunchconfiguration.h>
#include <kdevplatform/interfaces/ilauncher.h>
#include <kdevplatform/interfaces/ilaunchmode.h>
#include <kdevplatform/interfaces/interfacesexport.h>
#include <kdevplatform/interfaces/ipartcontroller.h>
#include <kdevplatform/interfaces/iplugin.h>
#include <kdevplatform/interfaces/iplugincontroller.h>
#include <kdevplatform/interfaces/iproject.h>
#include <kdevplatform/interfaces/iprojectcontroller.h>
#include <kdevplatform/interfaces/iruncontroller.h>
#include <kdevplatform/interfaces/iselectioncontroller.h>
#include <kdevplatform/interfaces/isession.h>
#include <kdevplatform/interfaces/isourceformatter.h>
#include <kdevplatform/interfaces/isourceformattercontroller.h>
#include <kdevplatform/interfaces/istatus.h>
#include <kdevplatform/interfaces/iuicontroller.h>
#include <kdevplatform/interfaces/launchconfigurationpage.h>
#include <kdevplatform/interfaces/launchconfigurationtype.h>
#include <kdevplatform/kdevplatformversion.h>
#include <kdevplatform/language/backgroundparser/backgroundparser.h>
#include <kdevplatform/language/backgroundparser/documentchangetracker.h>
#include <kdevplatform/language/backgroundparser/parsejob.h>
#include <kdevplatform/language/codecompletion/abstractincludefilecompletionitem.h>
#include <kdevplatform/language/codecompletion/codecompletion.h>
#include <kdevplatform/language/codecompletion/codecompletioncontext.h>
#include <kdevplatform/language/codecompletion/codecompletionhelper.h>
#include <kdevplatform/language/codecompletion/codecompletionitem.h>
#include <kdevplatform/language/codecompletion/codecompletionitemgrouper.h>
#include <kdevplatform/language/codecompletion/codecompletionmodel.h>
#include <kdevplatform/language/codecompletion/codecompletionworker.h>
#include <kdevplatform/language/codecompletion/normaldeclarationcompletionitem.h>
#include <kdevplatform/language/codegen/applychangeswidget.h>
#include <kdevplatform/language/codegen/astchangeset.h>
#include <kdevplatform/language/codegen/codegenerator.h>
#include <kdevplatform/language/codegen/coderepresentation.h>
#include <kdevplatform/language/codegen/createclass.h>
#include <kdevplatform/language/codegen/documentchangeset.h>
#include <kdevplatform/language/codegen/duchainchangeset.h>
#include <kdevplatform/language/codegen/overridespage.h>
#include <kdevplatform/language/codegen/utilities.h>
#include <kdevplatform/language/duchain/abstractfunctiondeclaration.h>
#include <kdevplatform/language/duchain/aliasdeclaration.h>
#include <kdevplatform/language/duchain/appendedlist.h>
#include <kdevplatform/language/duchain/arrayhelpers.h>
#include <kdevplatform/language/duchain/builders/abstractcontextbuilder.h>
#include <kdevplatform/language/duchain/builders/abstractdeclarationbuilder.h>
#include <kdevplatform/language/duchain/builders/abstractexpressionvisitor.h>
#include <kdevplatform/language/duchain/builders/abstracttypebuilder.h>
#include <kdevplatform/language/duchain/builders/abstractusebuilder.h>
#include <kdevplatform/language/duchain/classdeclaration.h>
#include <kdevplatform/language/duchain/classfunctiondeclaration.h>
#include <kdevplatform/language/duchain/classmemberdeclaration.h>
#include <kdevplatform/language/duchain/classmemberdeclarationdata.h>
#include <kdevplatform/language/duchain/codemodel.h>
#include <kdevplatform/language/duchain/declaration.h>
#include <kdevplatform/language/duchain/declarationdata.h>
#include <kdevplatform/language/duchain/declarationid.h>
#include <kdevplatform/language/duchain/duchain.h>
#include <kdevplatform/language/duchain/duchainbase.h>
#include <kdevplatform/language/duchain/duchainlock.h>
#include <kdevplatform/language/duchain/duchainobserver.h>
#include <kdevplatform/language/duchain/duchainpointer.h>
#include <kdevplatform/language/duchain/duchainregister.h>
#include <kdevplatform/language/duchain/duchainutils.h>
#include <kdevplatform/language/duchain/ducontext.h>
#include <kdevplatform/language/duchain/ducontextdata.h>
#include <kdevplatform/language/duchain/dumpchain.h>
#include <kdevplatform/language/duchain/dumpdotgraph.h>
#include <kdevplatform/language/duchain/forwarddeclaration.h>
#include <kdevplatform/language/duchain/functiondeclaration.h>
#include <kdevplatform/language/duchain/functiondefinition.h>
#include <kdevplatform/language/duchain/identifier.h>
#include <kdevplatform/language/duchain/indexeditems.h>
#include <kdevplatform/language/duchain/indexedstring.h>
#include <kdevplatform/language/duchain/instantiationinformation.h>
#include <kdevplatform/language/duchain/namespacealiasdeclaration.h>
#include <kdevplatform/language/duchain/navigation/abstractdeclarationnavigationcontext.h>
#include <kdevplatform/language/duchain/navigation/abstractincludenavigationcontext.h>
#include <kdevplatform/language/duchain/navigation/abstractnavigationcontext.h>
#include <kdevplatform/language/duchain/navigation/abstractnavigationwidget.h>
#include <kdevplatform/language/duchain/navigation/navigationaction.h>
#include <kdevplatform/language/duchain/navigation/usescollector.h>
#include <kdevplatform/language/duchain/navigation/usesnavigationcontext.h>
#include <kdevplatform/language/duchain/navigation/useswidget.h>
#include <kdevplatform/language/duchain/parsingenvironment.h>
#include <kdevplatform/language/duchain/persistentsetmap.h>
#include <kdevplatform/language/duchain/persistentsymboltable.h>
#include <kdevplatform/language/duchain/referencecounting.h>
#include <kdevplatform/language/duchain/repositories/itemrepository.h>
#include <kdevplatform/language/duchain/repositories/typerepository.h>
#include <kdevplatform/language/duchain/safetycounter.h>
#include <kdevplatform/language/duchain/smartconverter.h>
#include <kdevplatform/language/duchain/specializationstore.h>
#include <kdevplatform/language/duchain/stringhelpers.h>
#include <kdevplatform/language/duchain/topducontext.h>
#include <kdevplatform/language/duchain/topducontextdata.h>
#include <kdevplatform/language/duchain/topducontextutils.h>
#include <kdevplatform/language/duchain/types/abstracttype.h>
#include <kdevplatform/language/duchain/types/alltypes.h>
#include <kdevplatform/language/duchain/types/arraytype.h>
#include <kdevplatform/language/duchain/types/constantintegraltype.h>
#include <kdevplatform/language/duchain/types/delayedtype.h>
#include <kdevplatform/language/duchain/types/enumerationtype.h>
#include <kdevplatform/language/duchain/types/enumeratortype.h>
#include <kdevplatform/language/duchain/types/functiontype.h>
#include <kdevplatform/language/duchain/types/identifiedtype.h>
#include <kdevplatform/language/duchain/types/indexedtype.h>
#include <kdevplatform/language/duchain/types/integraltype.h>
#include <kdevplatform/language/duchain/types/pointertype.h>
#include <kdevplatform/language/duchain/types/referencetype.h>
#include <kdevplatform/language/duchain/types/structuretype.h>
#include <kdevplatform/language/duchain/types/typealiastype.h>
#include <kdevplatform/language/duchain/types/typepointer.h>
#include <kdevplatform/language/duchain/types/typeregister.h>
#include <kdevplatform/language/duchain/types/typesystem.h>
#include <kdevplatform/language/duchain/types/typesystemdata.h>
#include <kdevplatform/language/duchain/types/typeutils.h>
#include <kdevplatform/language/duchain/types/unsuretype.h>
#include <kdevplatform/language/duchain/use.h>
#include <kdevplatform/language/editor/documentcursor.h>
#include <kdevplatform/language/editor/documentcursorobject.h>
#include <kdevplatform/language/editor/documentrange.h>
#include <kdevplatform/language/editor/documentrangeobject.h>
#include <kdevplatform/language/editor/editorintegrator.h>
#include <kdevplatform/language/editor/editorrevisiontracker.h>
#include <kdevplatform/language/editor/hashedstring.h>
#include <kdevplatform/language/editor/modificationrevision.h>
#include <kdevplatform/language/editor/modificationrevisionset.h>
#include <kdevplatform/language/editor/simplecursor.h>
#include <kdevplatform/language/editor/simplerange.h>
#include <kdevplatform/language/highlighting/codehighlighting.h>
#include <kdevplatform/language/interfaces/codecontext.h>
#include <kdevplatform/language/interfaces/editorcontext.h>
#include <kdevplatform/language/interfaces/iastcontainer.h>
#include <kdevplatform/language/interfaces/icodehighlighting.h>
#include <kdevplatform/language/interfaces/ilanguagesupport.h>
#include <kdevplatform/language/interfaces/iproblem.h>
#include <kdevplatform/language/interfaces/iquickopen.h>
#include <kdevplatform/language/interfaces/quickopendataprovider.h>
#include <kdevplatform/language/interfaces/quickopenfilter.h>
#include <kdevplatform/language/languageexport.h>
#include <kdevplatform/language/util/basicsetrepository.h>
#include <kdevplatform/language/util/includeitem.h>
#include <kdevplatform/language/util/navigationtooltip.h>
#include <kdevplatform/language/util/setrepository.h>
#include <kdevplatform/outputview/ioutputview.h>
#include <kdevplatform/outputview/ioutputviewmodel.h>
#include <kdevplatform/outputview/outputjob.h>
#include <kdevplatform/outputview/outputmodel.h>
#include <kdevplatform/outputview/outputviewexport.h>
#include <kdevplatform/project/builderjob.h>
#include <kdevplatform/project/importprojectjob.h>
#include <kdevplatform/project/interfaces/ibuildsystemmanager.h>
#include <kdevplatform/project/interfaces/iprojectbuilder.h>
#include <kdevplatform/project/interfaces/iprojectfilemanager.h>
#include <kdevplatform/project/projectbuildsetmodel.h>
#include <kdevplatform/project/projectconfigskeleton.h>
#include <kdevplatform/project/projectexport.h>
#include <kdevplatform/project/projectitemlineedit.h>
#include <kdevplatform/project/projectkcmodule.h>
#include <kdevplatform/project/projectmodel.h>
#include <kdevplatform/shell/core.h>
#include <kdevplatform/shell/documentcontroller.h>
#include <kdevplatform/shell/language.h>
#include <kdevplatform/shell/languagecontroller.h>
#include <kdevplatform/shell/mainwindow.h>
#include <kdevplatform/shell/partcontroller.h>
#include <kdevplatform/shell/partdocument.h>
#include <kdevplatform/shell/plugincontroller.h>
#include <kdevplatform/shell/project.h>
#include <kdevplatform/shell/projectcontroller.h>
#include <kdevplatform/shell/selectioncontroller.h>
#include <kdevplatform/shell/session.h>
#include <kdevplatform/shell/sessioncontroller.h>
#include <kdevplatform/shell/shellexport.h>
#include <kdevplatform/shell/shellextension.h>
#include <kdevplatform/shell/sourceformattercontroller.h>
#include <kdevplatform/shell/textdocument.h>
#include <kdevplatform/shell/uicontroller.h>
#include <kdevplatform/sublime/area.h>
#include <kdevplatform/sublime/areaindex.h>
#include <kdevplatform/sublime/areawalkers.h>
#include <kdevplatform/sublime/container.h>
#include <kdevplatform/sublime/controller.h>
#include <kdevplatform/sublime/document.h>
#include <kdevplatform/sublime/mainwindow.h>
#include <kdevplatform/sublime/mainwindowoperator.h>
#include <kdevplatform/sublime/sublimedefs.h>
#include <kdevplatform/sublime/sublimeexport.h>
#include <kdevplatform/sublime/tooldocument.h>
#include <kdevplatform/sublime/urldocument.h>
#include <kdevplatform/sublime/view.h>
#include <kdevplatform/tests/autotestshell.h>
#include <kdevplatform/tests/kdevplatformtestsexport.h>
#include <kdevplatform/tests/kdevsignalspy.h>
#include <kdevplatform/tests/testcore.h>
#include <kdevplatform/util/activetooltip.h>
#include <kdevplatform/util/commandexecutor.h>
#include <kdevplatform/util/convenientfreelist.h>
#include <kdevplatform/util/embeddedfreetree.h>
#include <kdevplatform/util/environmentgrouplist.h>
#include <kdevplatform/util/environmentselectionwidget.h>
#include <kdevplatform/util/executecompositejob.h>
#include <kdevplatform/util/focusedtreeview.h>
#include <kdevplatform/util/google/hash_fun.h>
#include <kdevplatform/util/google/sparsehash/densehashtable.h>
#include <kdevplatform/util/google/sparsehash/sparseconfig.h>
#include <kdevplatform/util/google/sparsehash/sparsehashtable.h>
#include <kdevplatform/util/google/type_traits.h>
#include <kdevplatform/util/kdevstringhandler.h>
#include <kdevplatform/util/kdevvarlengtharray.h>
#include <kdevplatform/util/ksharedobject.h>
#include <kdevplatform/util/processlinemaker.h>
#include <kdevplatform/util/pushvalue.h>
#include <kdevplatform/util/utilexport.h>
#include <kdevplatform/vcs/dvcs/dvcsevent.h>
#include <kdevplatform/vcs/dvcs/dvcsjob.h>
#include <kdevplatform/vcs/dvcs/dvcsplugin.h>
#include <kdevplatform/vcs/interfaces/ibasicversioncontrol.h>
#include <kdevplatform/vcs/interfaces/ibranchingversioncontrol.h>
// #include <kdevplatform/vcs/interfaces/ibrowsableversioncontrol.h>
#include <kdevplatform/vcs/interfaces/icentralizedversioncontrol.h>
#include <kdevplatform/vcs/interfaces/idistributedversioncontrol.h>
#include <kdevplatform/vcs/interfaces/irepositoryversioncontrol.h>
#include <kdevplatform/vcs/models/vcsannotationmodel.h>
#include <kdevplatform/vcs/models/vcseventmodel.h>
#include <kdevplatform/vcs/models/vcsitemeventmodel.h>
#include <kdevplatform/vcs/vcsannotation.h>
#include <kdevplatform/vcs/vcsdiff.h>
#include <kdevplatform/vcs/vcsevent.h>
#include <kdevplatform/vcs/vcsexport.h>
#include <kdevplatform/vcs/vcsjob.h>
#include <kdevplatform/vcs/vcslocation.h>
#include <kdevplatform/vcs/vcspluginhelper.h>
#include <kdevplatform/vcs/vcsrevision.h>
#include <kdevplatform/vcs/vcsstatusinfo.h>
#include <kdevplatform/vcs/widgets/vcsannotationwidget.h>
#include <kdevplatform/vcs/widgets/vcscommitdialog.h>
#include <kdevplatform/vcs/widgets/vcsdiffwidget.h>
#include <kdevplatform/vcs/widgets/vcseventwidget.h>
#include <kdevplatform/vcs/widgets/vcsimportmetadatawidget.h>
